@@ -1,24 +1,15 @@
 from __future__ import annotations
 
 from pathlib import Path, PurePath
-from typing import Iterable, Mapping
+from typing import Iterable, Mapping, Tuple, Union, Optional, List
 
+from PIL import Image as PILImageModule
+from PIL.Image import Image
+from PIL.Image import Resampling
 from rich.console import Console, ConsoleOptions, RenderResult
 from rich.segment import Segment, Segments
 from rich.style import Style
 
-try:
-    from PIL import Image
-    from PIL.Image import Resampling
-
-    _PIL_INSTALLED = True
-except ImportError:
-    _PIL_INSTALLED = False
-
-
-class PixelsError(Exception):
-    pass
-
 
 class Pixels:
     def __init__(self) -> None:
@@ -26,15 +17,15 @@ class Pixels:
 
     @staticmethod
     def from_image(
-        image: "Image",
+        image: Image,
     ):
         segments = Pixels._segments_from_image(image)
         return Pixels.from_segments(segments)
 
     @staticmethod
     def from_image_path(
-        path: PurePath | str,
-        resize: tuple[int, int] | None = None,
+        path: Union[PurePath, str],
+        resize: Optional[Tuple[int, int]] = None,
     ) -> Pixels:
         """Create a Pixels object from an image. Requires 'image' extra dependencies.
 
@@ -42,21 +33,15 @@ class Pixels:
             path: The path to the image file.
             resize: A tuple of (width, height) to resize the image to.
         """
-        with Image.open(Path(path)) as image:
+        with PILImageModule.open(Path(path)) as image:
             segments = Pixels._segments_from_image(image, resize)
 
         return Pixels.from_segments(segments)
 
     @staticmethod
     def _segments_from_image(
-        image: "Image", resize: tuple[int, int] | None = None
+        image: Image, resize: Optional[Tuple[int, int]] = None
     ) -> list[Segment]:
-        if not _PIL_INSTALLED:
-            raise PixelsError(
-                "Methods like from_image and from_image_path require "
-                "the 'image' extra dependencies to be installed."
-            )
-
         if resize:
             image = image.resize(resize, resample=Resampling.NEAREST)
 
@@ -68,7 +53,7 @@ class Pixels:
         segments = []
 
         for y in range(height):
-            this_row = []
+            this_row: List[Segment] = []
             row_append = this_row.append
 
             for x in range(width):
@@ -94,7 +79,9 @@ class Pixels:
         return pixels
 
     @staticmethod
-    def from_ascii(grid: str, mapping: Mapping[str, Segment] | None = None) -> Pixels:
+    def from_ascii(
+        grid: str, mapping: Optional[Mapping[str, Segment]] = None
+    ) -> Pixels:
         """
         Create a Pixels object from a 2D-grid of ASCII characters.
         Each ASCII character can be mapped to a Segment (a character and style combo),
@@ -124,9 +111,9 @@ class Pixels:
         yield self._segments or ""
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     console = Console()
-    images_path = Path(__file__).parent / "../.sample_data/images"
+    images_path = Path(__file__).parent / "../tests/.sample_data/images"
     pixels = Pixels.from_image_path(images_path / "bulbasaur.png")
     console.print(pixels)
 
